@@ -22,7 +22,7 @@ readXML <- FunctionGenerator(function(spec, doc, ...) {
     spec <- spec
     doc <- doc
     function(elem, language, id) {
-        tree <- XML::xmlInternalTreeParse(elem$content, asText = TRUE)
+        tree <- XML::xmlParse(elem$content, asText = TRUE)
         Content(doc) <- if ("Content" %in% names(spec))
             .xml_content(tree, spec[["Content"]])
         else
@@ -116,30 +116,6 @@ readRCV1asPlain <- readXML(spec = list(Author = list("unevaluated", ""),
                            Countries = list("attribute", "/newsitem/metadata/codes[@class='bip:countries:1.0']/code/@code")),
                            doc = PlainTextDocument())
 
-# readOOO needs unoconv (which in turn needs OpenOffice) installed
-readOOO <- FunctionGenerator(function(unoconvOptions = "", ...) {
-    unoconvOptions <- unoconvOptions
-    function(elem, language, id) {
-        tmp <- tempfile()
-        # Unfortunately unoconv does not have an output file option and writes the output to the same directory as the input
-        # In addition conversion to stdout may corrupt the zip file (odt) if writing it out via writeLines()
-        if (!all(file.copy(elem$uri, sprintf("%s.oo", tmp))))
-            stop(sprintf("cannot copy %s", elem$uri))
-        system(paste("unoconv -f odt", sprintf("%s.oo", tmp)))
-        meta.xml <- unzip(sprintf("%s.odt", tmp), "meta.xml", exdir = dirname(tmp))[1]
-
-        on.exit(file.remove(sprintf("%s.oo", tmp), sprintf("%s.odt", tmp), meta.xml))
-
-        root <- XML::xmlRoot(XML::xmlParse(meta.xml))
-
-        content <- system(paste("unoconv -f txt --stdout", shQuote(elem$uri)), intern = TRUE)
-        author <- XML::xpathSApply(root, "/office:document-meta/office:meta/dc:creator", XML::xmlValue)
-        datetimestamp <- as.POSIXlt(XML::xpathSApply(root, "/office:document-meta/office:meta/dc:date", XML::xmlValue))
-
-        PlainTextDocument(content, author, datetimestamp, id = id, language = language)
-    }
-})
-
 # readDOC needs antiword installed to be able to extract the text
 readDOC <- FunctionGenerator(function(AntiwordOptions = "", ...) {
     AntiwordOptions <- AntiwordOptions
